export function connect(config: any, user: any): Promise<any>;
/**
 * Retrieve and delete an email.
 *
 * @example
 * ```javascript
 * const email = makeRandomEmail(config, 'myTestCase');
 * const start = new Date();
 * await ... // register with email
 * const welcomeMail = await getMail(config, start, email, 'Welcome');
 * assert.strictEqual(welcomeMail.text.includes('Hello'));
 * assert.strictEqual(welcomeMail.html.includes('<p>Hello'));
 * ```
 * @param {import('./internal').TaskConfig} config The pentf configuration object.
 * @param {Date} since Earliest time the email can be sent. (To avoid finding the email of a prior test.)
 * @param {string} to receiveer email address (`config.email` if you have just one email address, often the result of `makeRandomEmail`)
 * @param {string} subjectContains Search string for the subject.
 * @param {number[]} wait_times How long to wait between checking email. By default, we wait about 3 minutes total.
 * @returns {Object} Email object with `html` and `text` properties.
 */
export function getMail(config: import('./internal').TaskConfig, since: Date, to: string, subjectContains: string, wait_times?: number[]): Object;
export function parseBody(body: any): {
    subject: any;
};
export function parseHeader(name: any, value: any): any;
export function shutdown(config: any): Promise<void>;
