export type Lock = {
    resource: string;
    expireIn: number;
    client?: string;
};
/**
 * Aquire locks on resources
 * @param {import('./config').Config} config
 * @param {import('./internal').RunnerState} state
 * @param {import('./internal').Task} task
 */
export function acquire(config: import('./config').Config, state: import('./internal').RunnerState, task: import('./internal').Task): Promise<boolean>;
/**
 * @param {import('./config').Config} config
 * @param {import('./internal').RunnerState} state
 * @param {import('./internal').Task} task
 */
export function acquireEventually(config: import('./config').Config, state: import('./internal').RunnerState, task: import('./internal').Task): Promise<boolean>;
/**
 * @typedef {{resource: string, expireIn: number, client?: string}} Lock
 */
/**
 * @param {import('./config').Config} config
 * @param {import('./internal').Task} task
 * @private
 */
export function annotateTaskResources(config: import('./config').Config, task: import('./internal').Task): void;
/**
 * @param {import('./config').Config} config
 * @param {import('./internal').RunnerState} state
 * @private
 */
export function init(config: import('./config').Config, state: import('./internal').RunnerState): Promise<void>;
/**
 * @param {import('./config').Config} config
 * @param {import('./internal').Task[]} tasks
 * @private
 */
export function listConflicts(config: import('./config').Config, tasks: import('./internal').Task[]): void;
/**
 * Release locks on resources
 * @param {import('./config').Config} config
 * @param {import('./internal').RunnerState} state
 * @param {import('./internal').Task} task
 */
export function release(config: import('./config').Config, state: import('./internal').RunnerState, task: import('./internal').Task): Promise<true | undefined>;
/**
 * @param {import('./config').Config} config
 * @param {import('./internal').RunnerState} state
 * @private
 */
export function shutdown(config: import('./config').Config, state: import('./internal').RunnerState): Promise<void>;
